@@ -5,7 +5,8 @@ import subprocess
 try:
     import en_core_web_sm
 except:
-    print("model not found, downloading model...")
+    print("model not found")
+    print("downloading model...")
     # os.system("python -m spacy download en_core_web_sm >> responses.text")
     subprocess.check_output('python -m spacy download en_core_web_sm >> respose.txt', shell=True)
 
